#
# spec file for package libsndfile
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           libsndfile
BuildRequires:  alsa-devel flac-devel gcc-c++ libvorbis-devel pkg-config sqlite-devel
Summary:        A Library to Handle Various Audio File Formats
Version:        1.0.23
Release:        3.4.1
License:        LGPLv2.1+
Group:          System/Libraries
Obsoletes:      libsnd
Provides:       libsnd
# bug437293
%ifarch ppc64
Obsoletes:      libsndfile-64bit
%endif
#
Source:         libsndfile-%{version}.tar.bz2
Source2:        baselibs.conf
Patch:          libsndfile-example-fix.diff
Patch1:         libsndfile-CVE-2011-2696.diff
Url:            http://www.mega-nerd.com/libsndfile/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Libsndfile is a C library for reading and writing sound files, such as
AIFF, AU, and WAV files, through one standard interface.  It can
currently read and write 8, 16, 24, and 32-bit PCM files as well as
32-bit floating point WAV files and a number of compressed formats.



Authors:
--------
    Erik de Castro Lopo <erikd@mega-nerd.com>

%package devel
License:        LGPLv2.1+
Summary:        Development package for the libsndfile library
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version} glibc-devel libstdc++-devel
Obsoletes:      libsndd
Provides:       libsndd
# bug437293
%ifarch ppc64
Obsoletes:      libsndfile-devel-64bit
%endif
#

%description devel
This package contains the files needed to compile programs that use the
libsndfile library.



Authors:
--------
    Erik de Castro Lopo <erikd@mega-nerd.com>

%prep
%setup -q
%patch
%patch1 -p1

%build
%define warn_flags -W -Wall -Wstrict-prototypes -Wpointer-arith -Wno-unused-parameter
# autoreconf --force --install
CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing %{warn_flags}"
export CFLAGS
%configure \
	--disable-static \
        --enable-sqlite \
	--with-pic
make %{?_smp_mflags}

%install
make DESTDIR="$RPM_BUILD_ROOT" install
# remove unnecessary files
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
# remove programs; built in another spec file
rm -rf $RPM_BUILD_ROOT%{_bindir}
rm -rf $RPM_BUILD_ROOT%{_mandir}/man1
# remove binaries from examples directory
make -C examples distclean
rm -rf $RPM_BUILD_ROOT%{_datadir}/doc/libsndfile1-dev

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-, root, root)
%{_libdir}/libsndfile.so.*

%files devel
%defattr(-, root, root)
%doc AUTHORS COPYING ChangeLog NEWS README
%doc doc/*.html doc/*.jpg doc/*.css doc/*.HOWTO
%{_libdir}/libsndfile.so
%{_includedir}/sndfile.h
%{_includedir}/sndfile.hh
%{_libdir}/pkgconfig/*.pc
%doc examples

%changelog
* Mon Jul 18 2011 tiwai@suse.de
- Fix VUL-0: libsndfile: Integer overflow by processing certain
  PAF files (CVE-2011-2696, bnc#705681)
* Mon Oct 11 2010 oliver.bengs@opensuse.org
- Update to version 1.0.23
- Upstream changes :
  * configure.ac src/version-metadata.rc.in src/Makefile.am
    Add version string resources to the windows DLL.
  * doc/api.html
    Update to add missing SF_FORMAT_* values. Closed Debian bug #545257.
  * NEWS README configure.ac doc/*.html
    Updates for 1.0.23 release.
  * Other minor bug fixes
* Fri Oct  8 2010 davejplater@gmail.com
- Update to version 1.0.22
- Upstream changes :
  * Bunch of minor bug fixes.
* Mon Aug 16 2010 tiwai@suse.de
- updated to version 1.0.21:
  * Bunch of minor bug fixes.
  * including VUL-1 divide-by-zero fix (bnc#631379)
* Wed Dec 16 2009 jengelh@medozas.de
- add baselibs.conf as a source
- enable parallel building
* Wed Jun  3 2009 dmueller@suse.de
- explicitely enable sqlite support to avoid random flipping
* Fri May 15 2009 tiwai@suse.de
- updated to version 1.0.20:
  * Fix for potential heap overflow
- enable ogg/vorbis support
* Fri Apr 24 2009 tiwai@suse.de
- built progs subpackage from an individual spec file to cut the
  circular dependency with jack.
* Wed Mar  4 2009 tiwai@suse.de
- updated to version 1.0.19:
  * Fix for CVE-2009-0186 (bnc#481769 - VUL-0: libsndfile CAF
    Processing Integer Overflow Vulnerability)
  * Huge number of minor fixes as a result of static analysis
- remove INSTALL file from filelist
* Mon Feb  9 2009 tiwai@suse.de
- updated to version 1.0.18
  * Add Ogg/Vorbis support (disabled right now due to vorbis
    version mismatch; SVN version is required)
  * Remove captive FLAC library.
  * Many new features and bug fixes.
  * Generate Win32 and Win64 pre-compiled binaries.
- Dropped libsndfile-octave subpackage (as octave itself is
  dropped from FACTORY)
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Tue Oct 14 2008 meissner@suse.de
- prototype for memset
* Tue May  6 2008 tiwai@suse.de
- fix missing initializations in demo programs (bnc#351128)
* Tue Apr 15 2008 schwab@suse.de
- Fix configure script.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Mon Mar 10 2008 crrodriguez@suse.de
- remove explicit-lib-dependencies
- fix -devel package dependencies
* Thu Sep 20 2007 tiwai@suse.de
- VUL-0: Heap-based buffer overflow in flac.c (#326070,
  CVE-2007-4974)
* Mon Apr 16 2007 tiwai@suse.de
- Move docs and manpages to appropriate sub-packages (#264820)
- Remove static library (#264820)
* Mon Apr 16 2007 schwab@suse.de
- Fix quoting in autoconf macros.
* Fri Apr 13 2007 tiwai@suse.de
- fix FLAC-1.1.4 support.
* Fri Sep  1 2006 tiwai@suse.de
- updated to version 1.0.17:
  * Add C++ wrapper sndfile.hh. Minor bug fixes and cleanups.
* Tue Jul  4 2006 tiwai@suse.de
- fix the build -- removed invalidly overridden HAVE_DECL_S_IRGRP
  definition in configure.ac.
* Mon May 29 2006 tiwai@suse.de
- added flac-devel to requires of devel sub package.
* Mon May 15 2006 tiwai@suse.de
- updated to version 1.0.16.
  * more format supports
  * code cleanups
  * fix memleaks
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Sep 30 2005 tiwai@suse.de
- updated to version 1.0.12.
- split example programs to progs sub-package.
- added -fno-strict-aliasing.
* Wed Nov 17 2004 tiwai@suse.de
- updated to version 1.0.11.
* Fri Sep  3 2004 tiwai@suse.de
- removed python from neededforbuild.
* Thu Aug  5 2004 tiwai@suse.de
- updated to version 1.0.10.
* Thu Feb 26 2004 tiwai@suse.de
- updated to version 1.0.7.
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Mon Sep 15 2003 kukuk@suse.de
- Set x bit on directories
* Fri Jun 20 2003 ro@suse.de
- added directories to filelist
* Fri Jun  6 2003 tiwai@suse.de
- updated to version 1.0.5.
* Tue May 13 2003 pthomas@suse.de
- Put Octave interface files into an own subpackage.
* Thu Feb 13 2003 pthomas@suse.de
- Compile with all usefull warnings and fix all places where the
  compiler warned.
- Fix configure to use $libdir instead of $prefix/lib for reporting.
* Tue Feb  4 2003 tiwai@suse.de
- updated to version 1.0.4.
* Fri Jan 17 2003 tiwai@suse.de
- added %%run_ldconfig to %%post.
* Thu Jan 16 2003 tiwai@suse.de
- updated to version 1.0.3.
- added *.la to devel package.
* Mon Nov 25 2002 tiwai@suse.de
- updated to version 1.0.2.
* Fri Sep 20 2002 tiwai@suse.de
- updated to version 1.0.1.
* Mon Aug 19 2002 tiwai@suse.de
- updated to version 1.0.0 final.
* Fri Aug  2 2002 tiwai@suse.de
- updated to version 1.0.0rc3.
* Tue Jun 25 2002 tiwai@suse.de
- updated to version 1.0.0rc2.
* Fri Apr 12 2002 tiwai@suse.de
- set %%__libdir.
- use make install as default instead of install-strip.
* Thu Feb  7 2002 tiwai@suse.de
- fixed build on s390x.
* Fri Dec  7 2001 tiwai@suse.de
- fixed group tag (System -> System Environment)
* Thu Dec  6 2001 tiwai@suse.de
- removed binaries from alsa-devel examples directory.
* Wed Nov 21 2001 tiwai@suse.de
- updated to ver.0.0.27.
* Wed Oct 17 2001 tiwai@suse.de
- updated to ver.0.0.26.
  + Added sf_command () interface.
  + Added support for IRCAM files.
  + Minor bug fixes.
* Tue Aug 28 2001 tiwai@suse.de
- updated to ver.0.0.24.
  + Added support for 32 bit floating point AIFC files, little endian AIFC
    files and 16, 24 and 32 bit Sphere NIST files.
  + Massive refactoring of internal code.
  + Added read and write handling of PEAK chunks on AIFF and WAV files.
  + Added read support for REX files (Propellerheads Reason).
  + Added sf_read_float () and sf_write_float () interfaces.
  + Minor bug fixes.
- changed group tag to System/Libraries
* Fri Aug  3 2001 tiwai@suse.de
- fixed compile on s390.
* Thu Jun  7 2001 tiwai@suse.de
- fixed compile with the latest libtool & autoconf.
* Tue Apr  3 2001 kukuk@suse.de
- move *.so files into devel package
- Remove kernel_header requires
- Fix glibc-devel dependencies
* Wed Dec 13 2000 tiwai@suse.de
- fixed compile on ia64.
* Thu Nov  2 2000 ro@suse.de
- changed Group to Development/Libraries (old group did not exist)
* Thu Nov  2 2000 tiwai@suse.de
- Updated to 0.0.22.
- Changed for long package-name support (libsnd -> libsndfile,
  libsndd -> libsndfile-devel).
* Tue Sep 26 2000 tiwai@suse.de
- changed to bzip2.
- added suse_update_config.
* Wed Sep  6 2000 tiwai@suse.de
- Initial version: 0.0.21.
